pub struct RocketMQSerializable;Implementations
Sourceimpl RocketMQSerializable
impl RocketMQSerializable
Sourcepub fn write_str(buf: &mut BytesMut, use_short_length: bool, s: &str) -> usize
pub fn write_str(buf: &mut BytesMut, use_short_length: bool, s: &str) -> usize
Optimized string write with inline hint for better performance
Sourcepub fn read_str(
buf: &mut BytesMut,
use_short_length: bool,
limit: usize,
) -> RocketMQResult<Option<CheetahString>>
pub fn read_str( buf: &mut BytesMut, use_short_length: bool, limit: usize, ) -> RocketMQResult<Option<CheetahString>>
Optimized string read with enhanced boundary checks and zero-copy
Sourcepub fn rocketmq_protocol_encode(
cmd: &mut RemotingCommand,
buf: &mut BytesMut,
) -> usize
pub fn rocketmq_protocol_encode( cmd: &mut RemotingCommand, buf: &mut BytesMut, ) -> usize
Optimized ROCKETMQ protocol encoding with reduced allocations
pub fn rocket_mq_protocol_encode_bytes(cmd: &RemotingCommand) -> Bytes
Sourcepub fn map_serialize(
map: &HashMap<CheetahString, CheetahString>,
) -> Option<BytesMut>
pub fn map_serialize( map: &HashMap<CheetahString, CheetahString>, ) -> Option<BytesMut>
Optimized map serialization with pre-calculated capacity
pub fn cal_total_len(remark_len: usize, ext_len: usize) -> usize
pub fn rocket_mq_protocol_decode( header_buffer: &mut BytesMut, header_len: usize, ) -> RocketMQResult<RemotingCommand>
Sourcepub fn map_deserialize(
buffer: &mut BytesMut,
len: usize,
) -> RocketMQResult<HashMap<CheetahString, CheetahString>>
pub fn map_deserialize( buffer: &mut BytesMut, len: usize, ) -> RocketMQResult<HashMap<CheetahString, CheetahString>>
Optimized map deserialization with capacity hint and better error handling